diff --git a/app/models/issue.rb b/app/models/issue.rb
index 942b654..4209a51 100644
--- a/app/models/issue.rb
+++ b/app/models/issue.rb
@@ -530,6 +530,36 @@ class Issue < ActiveRecord::Base
   # Returns a string of css classes that apply to the issue
   def css_classes
     s = "issue status-#{status.position} priority-#{priority.position}"
+    if IssuePriority.count == 2
+      if priority.position == 2
+        s << ' priority-high'
+      end
+    elsif IssuePriority.count == 3
+      if priority.position == 1
+        s << ' priority-low'
+      elsif priority.position == 3
+        s << ' priority-high'
+      end
+    elsif IssuePriority.count == 4
+      if priority.position == 1
+        s << ' priority-low'
+      elsif priority.position == 3
+        s << ' priority-high'
+      elsif priority.position == 4
+        s << ' priority-urgent'
+      end
+    elsif IssuePriority.count > 4
+      max_pos = IssuePriority.maximum(:position)
+      if priority.position == 1
+        s << ' priority-low'
+      elsif priority.position == max_pos - 2
+        s << ' priority-high'
+      elsif priority.position == max_pos - 1
+        s << ' priority-urgent'
+      elsif priority.position == max_pos
+        s << ' priority-immediate'
+      end
+    end      
     s << ' closed' if closed?
     s << ' overdue' if overdue?
     s << ' created-by-me' if User.current.logged? && author_id == User.current.id
diff --git a/public/themes/alternate/stylesheets/application.css b/public/themes/alternate/stylesheets/application.css
index ef2c8cf..8e32ad8 100644
--- a/public/themes/alternate/stylesheets/application.css
+++ b/public/themes/alternate/stylesheets/application.css
@@ -28,33 +28,33 @@ table.list thead th {
 /* Issues grid styles by priorities (provided by Wynn Netherland) */
 table.list tr.issue a { color: #666; }
 
-tr.odd.priority-5, table.list tbody tr.odd.priority-5:hover { color: #900; font-weight: bold; }
-tr.odd.priority-5 { background: #ffc4c4; }
-tr.even.priority-5, table.list tbody tr.even.priority-5:hover { color: #900; font-weight: bold; }
-tr.even.priority-5 { background: #ffd4d4; }
-tr.priority-5 a, tr.priority-5:hover a { color: #900; }
-tr.odd.priority-5 td, tr.even.priority-5 td { border-color: #ffb4b4; }
+tr.odd.priority-immediate, table.list tbody tr.odd.priority-immediate:hover { color: #900; font-weight: bold; }
+tr.odd.priority-immediate { background: #ffc4c4; }
+tr.even.priority-immediate, table.list tbody tr.even.priority-immediate:hover { color: #900; font-weight: bold; }
+tr.even.priority-immediate { background: #ffd4d4; }
+tr.priority-immediate a, tr.priority-immediate:hover a { color: #900; }
+tr.odd.priority-immediate td, tr.even.priority-immediate td { border-color: #ffb4b4; }
 
-tr.odd.priority-4, table.list tbody tr.odd.priority-4:hover { color: #900; }
-tr.odd.priority-4 { background: #ffc4c4; }
-tr.even.priority-4, table.list tbody tr.even.priority-4:hover { color: #900; }
-tr.even.priority-4 { background: #ffd4d4; }
-tr.priority-4 a { color: #900; }
-tr.odd.priority-4 td, tr.even.priority-4 td { border-color: #ffb4b4; }
+tr.odd.priority-urgent, table.list tbody tr.odd.priority-urgent:hover { color: #900; }
+tr.odd.priority-urgent { background: #ffc4c4; }
+tr.even.priority-urgent, table.list tbody tr.even.priority-urgent:hover { color: #900; }
+tr.even.priority-urgent { background: #ffd4d4; }
+tr.priority-urgent a { color: #900; }
+tr.odd.priority-urgent td, tr.even.priority-urgent td { border-color: #ffb4b4; }
 
-tr.odd.priority-3, table.list tbody tr.odd.priority-3:hover { color: #900; }
-tr.odd.priority-3 { background: #fee; }
-tr.even.priority-3, table.list tbody tr.even.priority-3:hover { color: #900; }
-tr.even.priority-3 { background: #fff2f2; }
-tr.priority-3 a { color: #900; }
-tr.odd.priority-3 td, tr.even.priority-3 td { border-color: #fcc; }
+tr.odd.priority-high, table.list tbody tr.odd.priority-high:hover { color: #900; }
+tr.odd.priority-high { background: #fee; }
+tr.even.priority-high, table.list tbody tr.even.priority-high:hover { color: #900; }
+tr.even.priority-high { background: #fff2f2; }
+tr.priority-high a { color: #900; }
+tr.odd.priority-high td, tr.even.priority-high td { border-color: #fcc; }
 
-tr.odd.priority-1, table.list tbody tr.odd.priority-1:hover { color: #559; }
-tr.odd.priority-1 { background: #eaf7ff; }
-tr.even.priority-1, table.list tbody tr.even.priority-1:hover { color: #559; }
-tr.even.priority-1 { background: #f2faff; }
-tr.priority-1 a { color: #559; }
-tr.odd.priority-1 td, tr.even.priority-1 td { border-color: #add7f3; }
+tr.odd.priority-low, table.list tbody tr.odd.priority-low:hover { color: #559; }
+tr.odd.priority-low { background: #eaf7ff; }
+tr.even.priority-low, table.list tbody tr.even.priority-low:hover { color: #559; }
+tr.even.priority-low { background: #f2faff; }
+tr.priority-low a { color: #559; }
+tr.odd.priority-low td, tr.even.priority-low td { border-color: #add7f3; }
 
 /* Buttons */
 input[type="button"], input[type="submit"], input[type="reset"] { background-color: #f2f2f2; color: #222222; border: 1px outset #cccccc; }
